==> client-java-api-3.0.0-sources.jar: io/kubernetes/client/models/V1alpha1PodPresetListFluent.java <==
package io.kubernetes.client.models;

import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1alpha1PodPresetListFluent<A extends V1alpha1PodPresetListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A addToItems(int index,V1alpha1PodPreset item);
    public A setToItems(int index,V1alpha1PodPreset item);
    public A addToItems(V1alpha1PodPreset... items);
    public A addAllToItems(Collection<V1alpha1PodPreset> items);
    public A removeFromItems(V1alpha1PodPreset... items);
    public A removeAllFromItems(Collection<V1alpha1PodPreset> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PodPreset> getItems();
    public List<V1alpha1PodPreset> buildItems();
    public V1alpha1PodPreset buildItem(int index);
    public V1alpha1PodPreset buildFirstItem();
    public V1alpha1PodPreset buildLastItem();
    public V1alpha1PodPreset buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1alpha1PodPresetBuilder> predicate);
    public A withItems(List<V1alpha1PodPreset> items);
    public A withItems(V1alpha1PodPreset... items);
    public Boolean hasItems();
    public V1alpha1PodPresetListFluent.ItemsNested<A> addNewItem();
    public V1alpha1PodPresetListFluent.ItemsNested<A> addNewItemLike(V1alpha1PodPreset item);
    public V1alpha1PodPresetListFluent.ItemsNested<A> setNewItemLike(int index,V1alpha1PodPreset item);
    public V1alpha1PodPresetListFluent.ItemsNested<A> editItem(int index);
    public V1alpha1PodPresetListFluent.ItemsNested<A> editFirstItem();
    public V1alpha1PodPresetListFluent.ItemsNested<A> editLastItem();
    public V1alpha1PodPresetListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1alpha1PodPresetBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1PodPresetListFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1PodPresetListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1alpha1PodPresetListFluent.MetadataNested<A> editMetadata();
    public V1alpha1PodPresetListFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1PodPresetListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1PodPresetFluent<V1alpha1PodPresetListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1alpha1PodPresetListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}

==> client-java-api-5.0.0-sources.jar: io/kubernetes/client/models/V1alpha1PodPresetListFluent.java <==
package io.kubernetes.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.kubernetes.client.fluent.Fluent;
import io.kubernetes.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.kubernetes.client.fluent.Predicate;
import java.lang.StringBuffer;
import java.lang.Deprecated;
import java.util.Collection;
import java.util.List;
import java.lang.Boolean;

public interface V1alpha1PodPresetListFluent<A extends V1alpha1PodPresetListFluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A addToItems(int index,V1alpha1PodPreset item);
    public A setToItems(int index,V1alpha1PodPreset item);
    public A addToItems(V1alpha1PodPreset... items);
    public A addAllToItems(Collection<V1alpha1PodPreset> items);
    public A removeFromItems(V1alpha1PodPreset... items);
    public A removeAllFromItems(Collection<V1alpha1PodPreset> items);
    
/**
 * This method has been deprecated, please use method buildItems instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PodPreset> getItems();
    public List<V1alpha1PodPreset> buildItems();
    public V1alpha1PodPreset buildItem(int index);
    public V1alpha1PodPreset buildFirstItem();
    public V1alpha1PodPreset buildLastItem();
    public V1alpha1PodPreset buildMatchingItem(io.kubernetes.client.fluent.Predicate<V1alpha1PodPresetBuilder> predicate);
    public Boolean hasMatchingItem(io.kubernetes.client.fluent.Predicate<V1alpha1PodPresetBuilder> predicate);
    public A withItems(List<V1alpha1PodPreset> items);
    public A withItems(V1alpha1PodPreset... items);
    public Boolean hasItems();
    public V1alpha1PodPresetListFluent.ItemsNested<A> addNewItem();
    public V1alpha1PodPresetListFluent.ItemsNested<A> addNewItemLike(V1alpha1PodPreset item);
    public V1alpha1PodPresetListFluent.ItemsNested<A> setNewItemLike(int index,V1alpha1PodPreset item);
    public V1alpha1PodPresetListFluent.ItemsNested<A> editItem(int index);
    public V1alpha1PodPresetListFluent.ItemsNested<A> editFirstItem();
    public V1alpha1PodPresetListFluent.ItemsNested<A> editLastItem();
    public V1alpha1PodPresetListFluent.ItemsNested<A> editMatchingItem(io.kubernetes.client.fluent.Predicate<V1alpha1PodPresetBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public V1ListMeta getMetadata();
    public V1ListMeta buildMetadata();
    public A withMetadata(V1ListMeta metadata);
    public Boolean hasMetadata();
    public V1alpha1PodPresetListFluent.MetadataNested<A> withNewMetadata();
    public V1alpha1PodPresetListFluent.MetadataNested<A> withNewMetadataLike(V1ListMeta item);
    public V1alpha1PodPresetListFluent.MetadataNested<A> editMetadata();
    public V1alpha1PodPresetListFluent.MetadataNested<A> editOrNewMetadata();
    public V1alpha1PodPresetListFluent.MetadataNested<A> editOrNewMetadataLike(V1ListMeta item);

    public interface ItemsNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1alpha1PodPresetFluent<V1alpha1PodPresetListFluent.ItemsNested<N>>{

        
    public N and();    public N endItem();
}
    public interface MetadataNested<N> extends io.kubernetes.client.fluent.Nested<N>,V1ListMetaFluent<V1alpha1PodPresetListFluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}


}
